<?php
/**
 * @version     $Id$
 * @package     Jumbotron
 * @subpackage  com_jumbotron
 * @copyright   Copyright 2010 - 2011 Jumbotron Sports. All rights reserved.
 * @license     GNU General Public License version 2 or later.
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * Jumbotron view.
 *
 * @package     Jumbotron
 * @subpackage  com_jumbotron
 * @since       2.7.0
 */
class JumbotronViewLevels extends JView
{
	/**
	 * @var    array  The array of records to display in the list.
	 * @since  2.7.0
	 */
	protected $items;

	/**
	 * @var    JPagination  The pagination object for the list.
	 * @since  2.7.0
	 */
	protected $pagination;

	/**
	 * @var    JObject	The model state.
	 * @since  2.7.0
	 */
	protected $state;

	/**
	 * Prepare and display the Levels view.
	 *
	 * @return  void
	 * @since   2.7.0
	 */
	public function display()
	{
		// Initialise variables.
		$this->items		= $this->get('Items');
		$this->pagination	= $this->get('Pagination');
		$this->state		= $this->get('State');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JError::raiseError(500, implode("\n", $errors));
			return false;
		}

		// Add the toolbar and display the view layout.
		$this->addToolbar();
		parent::display();
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 * @since   2.7.0
	 */
	protected function addToolbar()
	{
		// Initialise variables.
		$state	= $this->get('State');
		$canDo	= JumbotronHelper::getActions();

		JToolBarHelper::title(JText::_('COM_JUMBOTRON_TITLE_LEVELS'), 'jumbotron');

		if ($canDo->get('core.create')) {
			JToolBarHelper::addNew('Level.add', 'JTOOLBAR_NEW');
		}

		if ($canDo->get('core.edit')) {
			JToolBarHelper::editList('Level.edit', 'JTOOLBAR_EDIT');
		}

		if ($canDo->get('core.edit.state')) {
			JToolBarHelper::publishList('Levels.publish', 'JTOOLBAR_PUBLISH');
			JToolBarHelper::unpublishList('Levels.unpublish', 'JTOOLBAR_UNPUBLISH');
			JToolBarHelper::archiveList('Levels.archive','JTOOLBAR_ARCHIVE');
		}

		if ($state->get('filter.published') == -2 && $canDo->get('core.delete')) {
			JToolBarHelper::deleteList('', 'Levels.delete','JTOOLBAR_EMPTY_TRASH');
		} 
		else if ($canDo->get('core.edit.state')) {
			JToolBarHelper::trash('Levels.trash','JTOOLBAR_TRASH');
		}

		if ($canDo->get('core.admin')) {
			JToolBarHelper::preferences('com_jumbotron');
		}
	}
}